@@ -12,6 +12,7 @@ All sub commands take an optional connections argument to specify which monitor
 Unfortunately it's value is not always as expected. For example xrandr reports my VGA port as DP-2
 and one of the display ports as HDMI-1.
 You can check the connection name to use with list, it is given in parentheses after the name.
+You can manually set a connection name with `crandr config`.
 """
 
 import os
@@ -21,6 +22,7 @@ import subprocess
 import shlex
 import typing
 import importlib
+import pkgutil
 import configparser
 
 from . import model
@@ -307,15 +309,20 @@ def config(api: model.Api, args: argparse.Namespace) -> None:
 		if not fn:
 			fn = next(config_finder.iter_possible_config_files())
 			path = os.path.split(fn)[0]
+			resource_example_config = 'doc/example_config'
 			if args.verbose:
 				print(f'os.makedirs({path!r}, exist_ok=True)')
+				print(f'cp {resource_example_config!r} {fn!r}')
 			if not args.dry_run:
 				os.makedirs(path, exist_ok=True)
+				with open(fn, 'wt') as f:
+					f.write(get_resource_content(resource_example_config))
 		cmd = editor + ' ' + shlex.quote(fn)
 		if args.verbose:
 			print(cmd)
 		if not args.dry_run:
 			subprocess.run(cmd, shell=True)
+			parse_config()
 
 def config_fallback(config_finder: config_paths.ConfigPathFinder) -> None:
 	print('[not opening config file because EDITOR is not defined]')
@@ -328,6 +335,12 @@ def config_fallback(config_finder: config_paths.ConfigPathFinder) -> None:
 		for searched_path in config_finder.iter_possible_config_files():
 			print('- %s' % searched_path)
 
+def get_resource_content(resource_name: str) -> str:
+	#https://stackoverflow.com/a/58941536
+	raw = pkgutil.get_data(__name__, resource_name)
+	assert raw is not None
+	return raw.decode('utf-8')
+
 
 # ---------- version ----------
 
